/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * Copyright (C) 2002  Roni Hursti <ronih@luukku.com>                      *
 * All rights reserved.                                                    *
 *                                                                         *
 * This program is free software; you can redistribute it and/or modify    *
 * it under the terms of the GNU General Public License. See the file      *
 * COPYRIGHT for more information.                                         *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License along *
 * with this program; if not, write to the Free Software Foundation, Inc., *
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA                 *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

import java.util.ArrayList;

/**
 * Check default constructors  <code>ConstructorType</code>
 *
 * @author     <a href="mailto:roni.hursti@luukku.com">Roni Hursti</a>
 * @version    1.0
 * @see        ArrayList
 * @since      jdk1.2
 */

public final class ConstructorType {
  /* An arraylist of constructors */
  private final ArrayList constructors;

  /** Default Constructor
   */
  public ConstructorType() {
    constructors = new ArrayList();
  }

  /** Fill list
   * @param index the upper limit to fill list to
   * @param from the lower limit to fill list from
   */
  private void fillList(final int index, final int from) {
    for (int i = index; --i >= from; ) {
      constructors.add(new Boolean(false));
    }
  }

  /** add constructor elem
   * @param index to add the element
   * @param isDefConstructor element value
   */
  public void addConstructor(final int index,
                             final boolean isDefConstructor) {
    int size = constructors.size();
    
    // System.out.println("addConstructor[" +index+" ],"+isDefConstructor);
    // System.out.println("size:" +size);
    if (index >= size) {
      fillList(index, size);
      constructors.add(new Boolean(isDefConstructor));
    }
    else if (isDefConstructor)
      constructors.set(index, new Boolean(isDefConstructor));

  }

  /** Remove an element for the array list
   * @param index removed element
   */
  public void remove(final int index) {
    int size = constructors.size();
    
    if (index >= size || index < 0)
      return;

    constructors.remove(index);
  }
  
  /** return constructor element
   * @param index which be returned
   * @return the element's value
   */
  public boolean returnConstructorElement(final int index) {
    int size = constructors.size();
    
    if (index >= size || index < 0)
      return false;
    
//    System.out.println("returnConstructorElement:" +index);
    return ((Boolean)constructors.get(index)).booleanValue();
  }

  /* print values */
  private void printValues() {
    System.out.println("size: " +constructors.size());
      
    for (int i = constructors.size(); --i >= 0;)
      System.out.println(i + " " +constructors.get(i));
    System.out.println("\n");
  }
  
}
