/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * Copyright (C) 1998-2001  Roni Hursti <ronih@luukku.com>                 *
 * All rights reserved.                                                    *
 *                                                                         *
 * This program is free software; you can redistribute it and/or modify    *
 * it under the terms of the GNU General Public License. See the file      *
 * COPYRIGHT for more information.                                         *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License along *
 * with this program; if not, write to the Free Software Foundation, Inc., *
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA                 *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/** This class consists information of 
 * numbers and equations for checking 
 * which equations (mul, div) can be replaced
 * for shift equations
 * @author     <a href="mailto:roni.hursti@luukku.com">Roni Hursti</a>
 * @version    1.0
 * @since      jdk1.2
 */
public final class ShiftElement {
  /* A value of shift element */
  private final int value;
  /** A type of shift element 
   * @see below for types
   */
  public int type;

  /* Constants types */
  private static final int NUMBER = 1;
  private static final int EQUATION = 2;
  private static final int OTHER = 4;

  /**
   * Default Constructor
   */
  public ShiftElement() {
    this.value = 0; type = OTHER;
  }
  
  /**
   * Constructor
   * @param value the value of the object
   */
  public ShiftElement(final int value) {
    this.value = value; type = 0;
  }

  /** Get number
   * @return number
   */
  public int getNumber() {
    return this.value;
  }
  /** Set type for number
   */
  public void setElementForNumber() {
    this.type = NUMBER;
  }
  /** Set type for equation
   */
  public void setElementForEquation() {
    this.type = EQUATION;
  }
  /** Set type for other
   */
  public void setElementForOther() {
    this.type = OTHER;
  }
  /* get element type, if it is a number type
   * return true
   * @return boolean value is the element type a number
   */
  public boolean isElementTypeNumber() {
    return this.type == NUMBER;
  }
  /* get element type, if it is a equation type
   * @return boolean value is the element type an equation
   * return true
   */
  public boolean isElementTypeEquation() {
    return this.type == EQUATION;
  }
}
