/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * Copyright (C) 2002  Roni Hursti <ronih@luukku.com>                      *
 * All rights reserved.                                                    *
 *                                                                         *
 * This program is free software; you can redistribute it and/or modify    *
 * it under the terms of the GNU General Public License. See the file      *
 * COPYRIGHT for more information.                                         *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License along *
 * with this program; if not, write to the Free Software Foundation, Inc., *
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA                 *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/** Class for variables
 * it includes is the variable (member variable) public
 * or protected and lineNumber
 * @author     <a href="mailto:roni.hursti@luukku.com">Roni Hursti</a>
 * @version    1.0
 * @since      jdk1.2
 */
public final class VariableType {
  /* Constants for modifiers */
  private static final int PRIVATE = 1;
  private static final int STATIC = 2; 
  private static final int METHOD = 4;
  
  /* Information of the variable's modifier type */
  private int type;
  /* Variable's linenumber */
  private final int lineNumber;

  /** Default constructor
  */
  public VariableType() {
    this.type = 0;
    this.lineNumber = 0;
  }
  /** Constructor
   * @param lineNumber line number
   */
  public VariableType(final int lineNumber) {
    this.type = 0;
    this.lineNumber = lineNumber;
  }

  /** Set private status
   */
  public void setPrivate() {
    this.type |= PRIVATE;
  }
  /** Set static status
   */
  public void setStatic() {
    this.type |= STATIC;
  }
  /** Set method parameter status
   */
  public void setMethodParameter() {
    this.type |= METHOD;
  }
  
  /** Return variable's linenumber
   * @return line number
   */
  public int getLine() { return lineNumber; }
  /** Return information is variable private
   * @return is variable a private
   */
  public boolean isPrivate() { return (type & PRIVATE) == PRIVATE; }
  /** Return information is variable static
   * @return is variable a static
   */
  public boolean isStatic() { return (type & STATIC) == STATIC; }
  /** Return information is variable method parameter
   * @return is variable a method parameter
   */
  public boolean isMethodParameter() { return (type & METHOD) == METHOD; }
}
